<?php


namespace App\Mobile\Synchronization\Controllers;

use App\Mobile\Synchronization\Resources\RouteResource;
use App\Mobile\Synchronization\Resources\SyncBuscaClientMobileResource;
use App\Mobile\Synchronization\Resources\SyncAllClientsResource;
use App\Mobile\Synchronization\Resources\SyncAllLoggedUserClientsResource;
use App\Mobile\Synchronization\Resources\SyncPersonModalityClientResource;
use App\Mobile\Synchronization\Resources\FillEmptyRouteResource;
use Freelabois\LaravelQuickstart\Extendables\CrudController;
use Illuminate\Support\Facades\Lang;
use Schaffen\Core\Person\Repositories\PersonModalityRepository;
use Schaffen\Financial\BillingRoute\Managers\RouteManager;
use Schaffen\Financial\BillingRoute\Managers\SalesmanRouteManager;
use Schaffen\Financial\BillingRoute\Repositories\RouteRepository;
use Schaffen\Financial\BillingRoute\Repositories\ClientRouteRepository;
use Illuminate\Http\Request;
use Schaffen\Financial\BillingRoute\Repositories\SalesmanRouteRepository;


class RouteController extends CrudController
{
    protected string $resource = RouteResource::class;

    public function __construct(
        RouteManager          $manager,
        RouteRepository       $repository,
        SalesmanRouteManager  $salesman_route_manager,
        SalesmanRouteRepository $salesman_route_repository,
        ClientRouteRepository $client_route_repository,
        PersonModalityRepository $person_modality_repository
    )
    {
        parent::__construct($manager, $repository);
        $this->client_route_repository = $client_route_repository;
        $this->salesman_route_manager = $salesman_route_manager;
        $this->salesman_route_repository = $salesman_route_repository;
        $this->person_modality_repository = $person_modality_repository;
    }

    public function index()
    {
        $user = auth()->user();
        $request = \request();
        $value = $this->salesman_route_manager->buscaRotasVendedor($user);
        $per_page = $sanitized['per_page'] ?? false;
        if ($value == 1){
            $rota_vazia = $this->salesman_route_repository->list(['rov_fk_pes_codigo' => $user['usu_fk_pes_codigo']], ['route']);
            $request['rot_codigo'] = $rota_vazia[0]->rov_codigo;
            $request['rot_descricao'] = $rota_vazia[0]->route->rot_descricao;

            return new FillEmptyRouteResource($this->person_modality_repository->list(['pem_fk_mdd_codigo' => 3], [], $per_page));
        } else if ($value == 2){
            return RouteResource::collection($this->salesman_route_repository->list(['rov_fk_pes_codigo' => $user['usu_fk_pes_codigo']], ['route'], $per_page));
        }
    }

    public function store()
    {
        throw new \Exception(Lang::get('exceptions.command.invalid'), 403);
    }

    public function update($id)
    {
        throw new \Exception(Lang::get('exceptions.command.invalid'), 403);
    }

    public function buscarCliente(Request $request)
    {
        $sanitized = $request->all();
        return SyncBuscaClientMobileResource::collection($this->manager->buscaCliente($sanitized));
    }

    public function todosClientesEmRota(Request $request)
    {
        $sanitized = $request->all();
        $per_page = $sanitized['per_page'] ?? false;
        return SyncAllClientsResource::collection($this->client_route_repository->list([], ['person'], $per_page));
    }

    public function clientsAll(Request $request)
    {
        $sanitized = $request->all();
        $per_page = $sanitized['per_page'] ?? false;
        $person_modality_repository = app()->make(PersonModalityRepository::class);
        return SyncPersonModalityClientResource::collection($person_modality_repository->list(['pem_fk_mdd_codigo' => 3], ['person'], $per_page));
    }

    public function rotaUsuarioLogado()
    {
        $values['pes_codigo'] = auth()->user()['usu_fk_pes_codigo'];
        return SyncAllLoggedUserClientsResource::collection($this->salesman_route_repository->list(['rov_fk_pes_codigo' => $values], ['route']));
    }

}
