<?php

namespace App\Mobile\Synchronization\Controllers;

use App\Mobile\Synchronization\Resources\SyncEstoqueResource;
use App\Mobile\Synchronization\Resources\SyncPaymentFormResource;
use App\Mobile\Synchronization\Resources\SyncProductResource;
use Freelabois\LaravelQuickstart\Extendables\CrudController;
use Schaffen\Core\PaymentForm\Managers\PaymentFormManager;
use Schaffen\Core\Person\Repositories\PersonRepository;
use Schaffen\Core\Product\Managers\ProductManager;
use Schaffen\Core\Product\Repositories\ProductRepository;
use Illuminate\Http\Request;
use Schaffen\Core\User\Repositories\UserRepository;


class SyncProductController extends CrudController
{
    protected $resource = SyncProductResource::class;

    public function __construct(
        ProductManager    $manager,
        ProductRepository $repository
    )
    {
        parent::__construct($manager, $repository);
        $this->manager = $manager;
        $this->repository = $repository;
    }

    public function produtosMobile()
    {
        return SyncProductResource::collection($this->manager->produtosMobile());
    }

    public function index()
    {
        $produtos = $this->manager->getProdutosMobile();
        $produtos_mobile = [];
        foreach ($produtos as $produto) {
            if($produto->product_variety->product_mobile->pro_mobile == 1){
                $produtos_mobile[] = $produto;
            }
        }
        return SyncProductResource::collection($produtos_mobile);
    }

    public function formasDePagamento()
    {
        $forma_pagamento_manager = app()->make(PaymentFormManager::class);
        return SyncPaymentFormResource::collection($forma_pagamento_manager->paymentFormsMobile());
    }

    public function buscaEstoque(Request $request)
    {
        $sanitized = $request->all();
        return SyncEstoqueResource::collection($this->manager->buscaEstoque($sanitized));
    }


}
