<?php

namespace App\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Support\Facades\Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * The path to the "home" route for your application.
     *
     * @var string
     */
    public const HOME = '/home';
    /**
     * This namespace is applied to your controller routes.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'App\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @return void
     */
    public function boot()
    {
        //

        parent::boot();
    }

    /**
     * Define the routes for the application.
     *
     * @return void
     */
    public function map()
    {
        $this->mapApiRoutes();
        $this->mapMobileRoutes();
        $this->mapWebRoutes();
        $this->mapDocumentsRoutes();

        //
    }

    /**
     * Define the "api" routes for the application.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::prefix('api')
            ->middleware('api')
            ->namespace('App\RestApi')
            ->name('rest.')
            ->group(base_path('routes/api.php'));
    }

    /**
     * Define the "mobile" routes for the application.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapMobileRoutes()
    {
        Route::prefix('api/mobile')
            ->middleware('api')
            ->namespace('App\Mobile')
            ->name('mobile.')
            ->group(base_path('routes/mobile.php'));
    }

    /**
     * Define the "web" routes for the application.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        Route::middleware('web')
            ->namespace($this->namespace)
            ->group(base_path('routes/web.php'));
    }


    /**
     * Define the "documents" routes for the application.
     *
     * These routes all documentations from advanced-line.
     *
     * @return void
     */
    protected function mapDocumentsRoutes()
    {
        Route::prefix('documents')
            ->middleware('documents')
            ->namespace('App\Documents')
            ->name('documents.')
            ->group(base_path('routes/documents.php'));
    }
}
